@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2015 Cyan, Inc.
-# Copyright 2017, 2018, 2019 Ciena Corporation
+# Copyright 2017, 2018, 2019, 2021 Ciena Corporation
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,15 +19,13 @@
 Low level network client for the Apache Kafka Message Broker.
 """
 
-from __future__ import absolute_import
-
 import logging
+import reprlib
 from collections import OrderedDict
 from datetime import datetime
 from functools import partial
 
 import attr
-from six.moves import reprlib
 from twisted.internet.defer import Deferred, fail, maybeDeferred
 from twisted.internet.protocol import ClientFactory
 from twisted.internet.task import deferLater
@@ -82,8 +80,7 @@ class _RequestState(object):
 
 
 _aLongerRepr = reprlib.Repr()
-_aLongerRepr.maxstring = 1024  # Python 2: str is bytes
-_aLongerRepr.maxother = 1024  # Python 3: bytes is not str
+_aLongerRepr.maxother = 1024  # bytes is not str, counts as "other"
 
 
 class _KafkaBrokerClient(ClientFactory):
