@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2015 Cyan, Inc.
-# Copyright 2016, 2017, 2018, 2019 Ciena Corporation
+# Copyright 2016, 2017, 2018, 2019, 2021 Ciena Corporation
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,6 @@
 
 High level network client for an Apache Kafka Cluster.
 """
-from __future__ import absolute_import, print_function
 
 import collections
 import logging
@@ -26,7 +25,6 @@ import random
 import warnings
 from functools import partial
 
-from six import raise_from
 from twisted.application.internet import backoffPolicy
 from twisted.internet import defer, task
 from twisted.internet.defer import CancelledError as t_CancelledError
@@ -482,12 +480,9 @@ class KafkaClient(object):
             log.error("Failed to load metadata for topics=%r",
                       topics,
                       exc_info=(failure.type, failure.value, failure.getTracebackObject()))
-            raise_from(
-                KafkaUnavailableError(
-                    "Failed to load metadata for topics={!r}: {}".format(topics, failure.value),
-                ),
-                failure.value,
-            )
+            raise KafkaUnavailableError(
+                "Failed to load metadata for topics={!r}: {}".format(topics, failure.value),
+            ) from failure.value
 
         # Send the request, add the handlers
         d = self._send_broker_unaware_request(requestId, request)
@@ -590,12 +585,9 @@ class KafkaClient(object):
                       exc_info=(err.type, err.value, err.getTracebackObject()))
             # Clear any stored value for the group's coordinator
             self.reset_consumer_group_metadata(group)
-            raise_from(
-                CoordinatorNotAvailable(
-                    "Coordinator for group {!r} not available".format(group),
-                ),
-                err.value,
-            )
+            raise CoordinatorNotAvailable(
+                "Coordinator for group {!r} not available".format(group),
+            ) from err.value
 
         def _propagate(result):
             [_, ds] = self._coordinator_fetches.pop(group)
@@ -917,7 +909,7 @@ class KafkaClient(object):
         """
         rr = _ReprRequest(request)
         issued = self.reactor.seconds()
-        cell = [None]  # single-element list: nonlocal for Python 2
+        failure = None
 
         if min_timeout is not None:
             timeout = max(self.timeout, min_timeout)
@@ -936,9 +928,10 @@ class KafkaClient(object):
             If we are configured to disconnect from the broker on timeout (to
             work around a Kafka bug), now is the time.
             """
+            nonlocal failure
             elapsed = self.reactor.seconds() - issued
             log.warning('_mrtb: Timing out %s after %.2f sec (%.2f sec elapsed)', rr, timeout, elapsed)
-            cell[0] = Failure(
+            failure = Failure(
                 RequestTimedOutError(
                     '{} timed out after {:.2f} sec ({:.2f} sec elapsed)'.format(rr, timeout, elapsed),
                 ),
@@ -956,10 +949,11 @@ class KafkaClient(object):
             Cancel the timeout delayed call if it is active. Otherwise the
             request timed out, so override its result with timeout failure.
             """
+            nonlocal failure
             if dc.active():
                 dc.cancel()
-            if cell[0] is not None:
-                return cell[0]
+            if failure is not None:
+                return failure
             return result
 
         if min_timeout is None:
