@@ -1,8 +1,18 @@
 # -*- coding: utf-8 -*-
 # Copyright 2015 Cyan, Inc.
 # Copyright 2016, 2017, 2018, 2019 Ciena Corporation
-
-from __future__ import absolute_import
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import logging
 from collections import defaultdict
@@ -192,7 +202,7 @@ class Producer(object):
 
             It will fail with `TypeError` when:
 
-            - *topic* is not text (`str` on Python 3, `str` or `unicode` on Python 2)
+            - *topic* is not `str`
             - *key* is not `bytes` or `None`
             - *msgs* is not a sequence of `bytes` or `None`
 
