@@ -18,15 +18,13 @@
 Test code for KafkaClient class.
 """
 
-from __future__ import absolute_import, division
-
 import logging
 import random
 import struct
 from itertools import cycle
 from pprint import pformat
+from unittest.mock import ANY, Mock
 
-from mock import ANY, Mock
 from twisted.internet.defer import Deferred
 from twisted.internet.error import ConnectError, ConnectionLost, UserError
 from twisted.internet.task import Clock
